@@ -12,20 +12,7 @@
 # so it should be enough just to <tt>require 'rack'</tt> in your code.
 
 module Rack
-  # The Rack protocol version number implemented.
-  VERSION = [1, 3].freeze
-  deprecate_constant :VERSION
-
-  VERSION_STRING = "1.3".freeze
-  deprecate_constant :VERSION_STRING
-
-  # The Rack protocol version number implemented.
-  def self.version
-    warn "Rack.version is deprecated and will be removed in Rack 3.1!", uplevel: 1
-    VERSION
-  end
-
-  RELEASE = "3.0.10"
+  RELEASE = "3.1.7"
 
   # Return the Rack release as a dotted string.
   def self.release
